@@ -173,7 +173,7 @@ class Plot:
     _allowed_keys = ["aspect", "axis", "axis_center", "backend",
     "detect_poles", "grid", "legend", "show", "size", "title", "use_latex",
     "xlabel", "ylabel", "zlabel", "xlim", "ylim", "zlim",
-    "xscale", "yscale", "zscale", "process_piecewise"]
+    "xscale", "yscale", "zscale", "process_piecewise", "polar_axis"]
     """contains a list of public keyword arguments supported by the series.
     It will be used to validate the user-provided keyword arguments.
     """
@@ -223,10 +223,12 @@ class Plot:
         self.zlabel = kwargs.get("zlabel", None)
         self.aspect = kwargs.get("aspect", "auto")
         self.axis_center = kwargs.get("axis_center", None)
+        self.camera = kwargs.get("camera", None)
         self.grid = kwargs.get("grid", True)
         self.xscale = kwargs.get("xscale", "linear")
         self.yscale = kwargs.get("yscale", "linear")
         self.zscale = kwargs.get("zscale", "linear")
+        self.polar_axis = kwargs.get("polar_axis", None)
         # NOTE: it would be nice to have detect_poles=True by default.
         # However, the correct detection also depends on the number of points
         # and the value of `eps`. Getting the detection right is likely to
@@ -319,7 +321,9 @@ class Plot:
             zlim=self.zlim,
             size=self.size,
             is_iplot=self.is_iplot,
-            use_latex=self._use_latex
+            use_latex=self._use_latex,
+            camera=self.camera,
+            polar_axis=self.polar_axis
         )
 
     def _init_cyclers(self):
