@@ -30,6 +30,11 @@ class PlotlyBackend(Plot):
             For example: ``dict(x=1, y=1, z=2)`` forces the z-axis to appear
             twice as big as the other two.
 
+    camera : dict, optional
+        A dictionary of keyword arguments that will be passed to the layout's
+        ``scene_camera`` in order to set the 3D camera orientation.
+        Refer to [#fn18]_ for more information.
+
     rendering_kw : dict, optional
         A dictionary of keywords/values which is passed to Matplotlib's plot
         functions to customize the appearance of lines, surfaces, images,
@@ -103,6 +108,7 @@ class PlotlyBackend(Plot):
     .. [#fn15] https://plotly.com/python/text-and-annotations/
     .. [#fn16] https://plotly.com/python/shapes/
     .. [#fn17] https://plotly.com/python/filled-area-plots/
+    .. [#fn18] https://plotly.com/python/3d-camera-controls/
 
 
     Notes
@@ -124,7 +130,7 @@ class PlotlyBackend(Plot):
 
     _library = "plotly"
     _allowed_keys = Plot._allowed_keys + [
-        "markers", "annotations", "fill", "rectangles"]
+        "markers", "annotations", "fill", "rectangles", "camera"]
 
     colorloop = []
     colormaps = []
@@ -297,6 +303,15 @@ class PlotlyBackend(Plot):
                     if (not s.is_point) and (not s.use_cm):
                         mode = "lines"
                     color = next(self._cl) if s.line_color is None else s.line_color
+                    # hover template
+                    ht = (
+                        "x: %{x}<br />y: %{y}<br />u: %{customdata}"
+                        if not s.is_complex
+                        else "x: %{x}<br />y: %{y}<br />Arg: %{customdata}"
+                    )
+                    if s.is_polar:
+                        ht = "r: %{r}<br />θ: %{theta}<br />u: %{customdata}"
+
                     lkw = dict(
                         name=s.get_label(self._use_latex),
                         line_color=color,
@@ -312,11 +327,7 @@ class PlotlyBackend(Plot):
                             showscale=self.legend and s.use_cm,
                         ),
                         customdata=param,
-                        hovertemplate=(
-                            "x: %{x}<br />y: %{y}<br />u: %{customdata}"
-                            if not s.is_complex
-                            else "x: %{x}<br />y: %{y}<br />Arg: %{customdata}"
-                        ),
+                        hovertemplate=ht,
                     )
                     if lkw["marker"]["showscale"]:
                         # only add a colorbar if required.
@@ -329,8 +340,14 @@ class PlotlyBackend(Plot):
                         lkw["marker"]["colorbar"] = self._create_colorbar(s.get_label(self._use_latex), True)
 
                     kw = merge({}, lkw, s.rendering_kw)
-                    cls = self._scatter_class(go, len(x))
-                    self._fig.add_trace(cls(x=x, y=y, **kw))
+
+                    if s.is_polar:
+                        kw.setdefault("thetaunit", "radians")
+                        cls = self._scatter_class(go, len(x), True)
+                        self._fig.add_trace(cls(r=y, theta=x, **kw))
+                    else:
+                        cls = self._scatter_class(go, len(x))
+                        self._fig.add_trace(cls(x=x, y=y, **kw))
                 else:
                     x, y = s.get_data()
                     color = next(self._cl) if s.line_color is None else s.line_color
@@ -935,7 +952,8 @@ class PlotlyBackend(Plot):
                     visible=self.grid,  # numbers below
                 ),
                 aspectmode=("manual" if isinstance(self.aspect, dict) else (self.aspect if self.aspect != "equal" else "auto")),
-                aspectratio=self.aspect if isinstance(self.aspect, dict) else None
+                aspectratio=self.aspect if isinstance(self.aspect, dict) else None,
+                camera=self.camera
             ),
         )
 
