@@ -1,6 +1,6 @@
 from spb.defaults import TWO_D_B, THREE_D_B, cfg
 from spb.ccomplex.complex import _build_series as _build_complex_series
-from spb.functions import _set_labels
+from spb.functions import _set_labels, _plot3d_wireframe_helper
 from spb.series import InteractiveSeries, _set_discretization_points
 from spb.vectors import _preprocess, _build_series as _build_vector_series
 from spb.utils import _plot_sympify, _unpack_args_extended, _validate_kwargs
@@ -352,7 +352,23 @@ class PanelLayout:
 
         merge = self._backend.merge
         kw = merge({}, default_kw, self._pane_kw)
-        self.pane = pn.pane.Pane(self.fig, **kw)
+        # NOTE: If the following import statement was located at the
+        # beginning of the file, there would be a circular import.
+        from spb import PB
+        if isinstance(self._backend, PB):
+            # NOTE: while pn.pane.Plotly can receive an instance of go.Figure,
+            # the update will be extremely slow, because after each trace
+            # is updated it will trigger an update event on the javascript
+            # side. Instead, by providing the following dictionary, first the
+            # traces are updated, then the pane creates the figure which will
+            # only be at last.
+            # TODO: can the backend be modified by adding data and layout
+            # attributes, avoiding the creation of the figure? The figure could
+            # be created inside the fig getter.
+            d = dict(data=list(self.fig.data), layout=self.fig.layout)
+            self.pane = pn.pane.Plotly(d, **kw)
+        else:
+            self.pane = pn.pane.Pane(self.fig, **kw)
 
     def layout_controls(self):
         return self.controls
@@ -360,13 +376,22 @@ class PanelLayout:
     def _action_post_update(self):
         # NOTE: If the following import statement was located at the
         # beginning of the file, there would be a circular import.
-        from spb import KB
+        from spb import KB, PB
 
         if not isinstance(self._backend, KB):
             # KB exhibits a strange behavior when executing the following
             # lines. For the moment, do not execute them with KB
             self.pane.param.trigger("object")
-            self.pane.object = self.fig
+            # self.pane.object = self.fig
+            if not isinstance(self._backend, PB):
+                self.pane.object = self.fig
+            else:
+                # NOTE: sadly, there is a bug with Panel and Plotly: if the
+                # user modifies the layout of the chart (for example zoom or
+                # rotate the view), the next update will reset them.
+                # https://github.com/holoviz/panel/issues/1801
+                d = dict(data=list(self.fig.data), layout=self.fig.layout)
+                self.pane.object = d
 
     def show(self):
         self._init_pane()
@@ -383,11 +408,13 @@ class PanelLayout:
         if not self._servable:
             return content
 
+        return self._create_template(content, True)
+
+    def _create_template(self, content, show=False):
         css = _CUSTOM_CSS + self._custom_css
         if len(self._name.strip()) == 0:
             css = _CUSTOM_CSS_NO_HEADER + self._custom_css
 
-
         # theme = pn.template.vanilla.VanillaDarkTheme if cfg["interactive"]["theme"] == "dark" else pn.template.vanilla.VanillaDefaultTheme
         # vanilla = pn.template.VanillaTemplate(title=self._name, theme=theme)
         # vanilla.main.append(content)
@@ -398,7 +425,9 @@ class PanelLayout:
         vanilla.main.append(content)
         vanilla.config.raw_css.append(css)
 
-        return vanilla.servable().show()
+        if show:
+            return vanilla.servable().show()
+        return vanilla
 
 
 def create_series(*args, **kwargs):
@@ -648,6 +677,7 @@ def create_series(*args, **kwargs):
                     )
             else:
                 series.append(InteractiveSeries(exprs, ranges, label, **kwargs))
+
     return series
 
 
@@ -690,8 +720,15 @@ class InteractivePlot(DynamicParam, PanelLayout):
         # create the series and apply the global labels and rendering keywords
         labels = kwargs.pop("label", [])
         rendering_kw = kwargs.pop("rendering_kw", None)
-        series = create_series(*args, iplot=self, **kwargs)
+        # NOTE: plot_list and List2DSeries are different then the other series.
+        # There is no List2DInteractiveSeries (as a design choice, for
+        # simplicity). Hence, that function is going to create the necessary
+        # series.
+        series = kwargs.pop("series", None)
+        if series is None:
+            series = create_series(*args, iplot=self, **kwargs)
         _set_labels(series, labels, rendering_kw)
+        series += _plot3d_wireframe_helper(series, **kwargs)
 
         if kwargs.get("is_complex", False):
             from spb.ccomplex.complex import _set_axis_labels
@@ -713,6 +750,13 @@ class InteractivePlot(DynamicParam, PanelLayout):
         """Return the backend"""
         return self._backend
 
+    @property
+    def pane_kw(self):
+        """Return the keyword arguments used to customize the wrapper to the
+        plot.
+        """
+        return self._pane_kw
+
     def save(self, *args, **kwargs):
         """Save the current figure.
         This is a wrapper to the backend's `save` function. Refer to the
@@ -766,7 +810,8 @@ class InteractivePlot(DynamicParam, PanelLayout):
             "throttled": self._throttled,
             "use_latex": self._use_latex,
             "params": self._original_params,
-            "show": False
+            "show": False,
+            "pane_kw": self._pane_kw
         }
 
         new_iplot = type(self)(**merge({}, backend_kw, panel_kw))
@@ -778,9 +823,9 @@ def iplot(*args, show=True, **kwargs):
     """Create an interactive application containing widgets and charts in order
     to study symbolic expressions.
 
-    Note that this function is already integrated with many of the usual
-    plotting functions, hence it is recommended to use those instead of
-    ``iplot`` because their documentation is more specific.
+    Note: this function is already integrated with many of the usual
+    plotting functions: since their documentation is more specific, it is
+    highly recommended to use those instead.
 
     However, the following documentation explains in details the main features
     exposed by the interactive module, which might not be included on the
@@ -981,27 +1026,24 @@ def iplot(*args, show=True, **kwargs):
     Examples
     ========
 
-    .. jupyter-execute::
-
-       from sympy import (symbols, sqrt, cos, exp, sin, pi, re, im,
-           Matrix, Plane, Polygon, I, log)
-       from spb.interactive import iplot
-       from spb.backends.matplotlib import MB
-       from spb.backends.bokeh import BB
-       from spb.backends.plotly import PB
-       x, y, z = symbols("x, y, z")
+    NOTE: the following examples use the ordinary plotting function because
+    ``iplot`` is already integrated with them.
 
     Surface plot between -10 <= x, y <= 10 with a damping parameter varying
-    from 0 to 1, with a default value of 0.15, discretized with 100 points
+    from 0 to 1, with a default value of 0.15, discretized with 50 points
     on both directions. Note the use of `threed=True` to specify a 3D plot.
     If `threed=False`, a contour plot will be generated.
 
-    .. jupyter-execute::
+    .. panel-screenshot::
 
+       from sympy import (symbols, sqrt, cos, exp, sin, pi, re, im,
+           Matrix, Plane, Polygon, I, log)
+       from spb import *
+       x, y, z = symbols("x, y, z")
        r = sqrt(x**2 + y**2)
        d = symbols('d')
        expr = 10 * cos(r) * exp(-r * d)
-       iplot(
+       plot3d(
            (expr, (x, -10, 10), (y, -10, 10)),
            params = { d: (0.15, 0, 1) },
            title = "My Title",
@@ -1009,8 +1051,11 @@ def iplot(*args, show=True, **kwargs):
            ylabel = "y axis",
            zlabel = "z axis",
            backend = PB,
-           n = 50,
-           threed = True
+           n = 51,
+           use_cm = True,
+           use_latex=False,
+           wireframe = True, wf_n1=15, wf_n2=15,
+           wf_rendering_kw={"line_color": "#003428", "line_width": 0.75}
        )
 
     A line plot of the magnitude of a transfer function, illustrating the use
@@ -1024,14 +1069,17 @@ def iplot(*args, show=True, **kwargs):
        correctly visualize very small or very big numbers.
     6. custom labeling of the parameter-sliders.
 
-    .. jupyter-execute::
+    .. panel-screenshot::
 
+       from sympy import (symbols, sqrt, cos, exp, sin, pi, re, im,
+           Matrix, Plane, Polygon, I, log)
+       from spb import *
        from bokeh.models.formatters import PrintfTickFormatter
        formatter = PrintfTickFormatter(format="%.3f")
        kp, t, z, o = symbols("k_P, tau, zeta, omega")
        G = kp / (I**2 * t**2 * o**2 + 2 * z * t * o * I + 1)
        mod = lambda x: 20 * log(sqrt(re(x)**2 + im(x)**2), 10)
-       iplot(
+       plot(
            (mod(G.subs(z, 0)), (o, 0.1, 100), "G(z=0)", {"line_dash": "dotted"}),
            (mod(G.subs(z, 1)), (o, 0.1, 100), "G(z=1)", {"line_dash": "dotted"}),
            (mod(G), (o, 0.1, 100), "G"),
@@ -1045,88 +1093,69 @@ def iplot(*args, show=True, **kwargs):
            xscale = "log",
            xlabel = "Frequency, omega, [rad/s]",
            ylabel = "Magnitude [dB]",
+           use_latex = False,
+       )
+
+    A line plot illustrating the Fouries series approximation of a saw tooth
+    wave and:
+
+    1. custom format of the value shown on the slider.
+    2. creation of an integer spinner widget. This is achieved by setting
+       ``None`` as one of the bounds of the integer parameter.
+
+    .. panel-screenshot::
+
+       from sympy import *
+       from spb import *
+       import param
+       from bokeh.models.formatters import PrintfTickFormatter
+
+       x, T, n, m = symbols("x, T, n, m")
+       sawtooth = frac(x / T)
+       # Fourier Series of a sawtooth wave
+       fs = S(1) / 2 - (1 / pi) * Sum(sin(2 * n * pi * x / T) / n, (n, 1, m))
+
+       formatter = PrintfTickFormatter(format="%.3f")
+       plot(
+           (sawtooth, (x, 0, 10), "f", {"line_dash": "dotted"}),
+           (fs, (x, 0, 10), "approx"),
+           params = {
+               T: (4, 0, 10, 80, formatter),
+               m: param.Integer(4, bounds=(1, None), label="Sum up to n ")
+           },
+           xlabel = "x",
+           ylabel = "y",
+           backend = BB,
            use_latex = False
        )
 
     A line plot with a parameter representing an angle in radians, but
     showing the value in degrees on its label:
 
-    .. jupyter-execute::
+    .. panel-screenshot::
+       :small-size: 800, 570
 
+       from sympy import sin, pi, symbols
+       from spb import *
        from bokeh.models.formatters import FuncTickFormatter
        # Javascript code is passed to `code=`
        formatter = FuncTickFormatter(code="return (180./3.1415926 * tick).toFixed(2)")
+       x, t = symbols("x, t")
 
-       iplot(
+       plot(
            (1 + x * sin(t), (x, -5, 5)),
            params = {
-               t: (0, -2 * pi, 2 * pi, 100, formatter, "theta [deg]")
-           },
-           backend = BB,
-           ylim = (-3, 4),
-           use_latex = False
-       )
-
-    A 3D slice-vector plot. Note: whenever we want to create parametric vector
-    plots, we should set `is_vector=True`.
-
-    .. jupyter-execute::
-
-       a, b = symbols("a, b")
-       iplot(
-           (Matrix([z * a, y * b, x]), (x, -5, 5), (y, -5, 5), (z, -5, 5)),
-           params = {
-               a: (1, 0, 5),
-               b: (1, 0, 5)
-           },
-           backend = PB,
-           is_vector = True,
-           n = 10,
-           slice = Plane((0, 0, 0), (0, 1, 0)),
-           quiver_kw = {"sizeref": 8},
-           use_latex = False
-       )
-
-    A parametric complex domain coloring plot. Note: whenever we want to create
-    parametric complex plots, we must set `is_complex=True`.
-
-    .. jupyter-execute::
-
-       iplot(
-           ((z**2 + 1) / (x * (z**2 - 1)), (z, -4 - 2 * I, 4 + 2 * I)),
-           params = {
-               x: (1, -2, 2)
+               t: (1, -2 * pi, 2 * pi, 100, formatter, "theta [deg]")
            },
            backend = MB,
-           is_complex = True,
-           coloring = "b",
-           grid = False,
-           use_latex = False
-       )
-
-    A parametric plot of a symbolic polygon. Note the use of `param` to create
-    an integer slider.
-
-    .. jupyter-execute::
-
-       import param
-       a, b, c, d = symbols('a:d')
-       iplot(
-           (Polygon((a, b), c, n=d), ),
-           params = {
-               a: (0, -2, 2),
-               b: (0, -2, 2),
-               c: (1, 0, 5),
-               d: param.Integer(3, softbounds=(3, 10), label="n"),
-           },
-           backend = BB,
-           is_filled = False,
-           aspect = "equal",
-           use_latex = False
+           xlabel = "x", ylabel = "y",
+           ylim = (-3, 4),
+           use_latex = False,
        )
 
     Combine together `InteractivePlot` and ``Plot`` instances. The same
-    parameters dictionary must be used for every ``iplot`` command. Note:
+    parameters dictionary must be used for every interactive plot command.
+    Note:
 
     1. the first plot dictates the labels, title and wheter to show the legend
        or not.
@@ -1138,14 +1167,16 @@ def iplot(*args, show=True, **kwargs):
        with ``p.backend``. Then, we can use the ``p.backend.fig`` attribute
        to retrieve the figure, or ``p.backend.save()`` to save the figure.
 
-    .. jupyter-execute::
+    .. panel-screenshot::
+       :small-size: 800, 570
 
-       from spb.functions import plot
-       u = symbols("u")
+       from sympy import sin, cos, symbols
+       from spb import *
+       x, u = symbols("x, u")
        params = {
            u: (1, 0, 2)
        }
-       p1 = iplot(
+       p1 = plot(
            (cos(u * x), (x, -5, 5)),
            params = params,
            backend = MB,
@@ -1156,7 +1187,7 @@ def iplot(*args, show=True, **kwargs):
            show = False,
            use_latex = False
        )
-       p2 = iplot(
+       p2 = plot(
            (sin(u * x), (x, -5, 5)),
            params = params,
            backend = MB,
@@ -1172,11 +1203,15 @@ def iplot(*args, show=True, **kwargs):
        p.show()
 
     Serves the interactive plot to a separate browser window. Note that
-    ``K3DBackend`` is not supported for this operation mode.
+    ``K3DBackend`` is not supported for this operation mode. Also note the
+    two ways to create a integer sliders.
 
-    .. code-block:: python
+    .. panel-screenshot::
+       :small-size: 800, 500
 
-       from spb.backends.bokeh import BB
+       from sympy import *
+       from spb import *
+       import param
        from bokeh.models.formatters import PrintfTickFormatter
        formatter = PrintfTickFormatter(format='%.4f')
 
@@ -1185,15 +1220,16 @@ def iplot(*args, show=True, **kwargs):
        phip = phi.diff(t)
        r1 = phip / (1 + phip)
 
-       iplot(
+       plot_polar(
            (r1, (t, 0, 2*pi)),
            params = {
                p1: (0.035, -0.035, 0.035, 50, formatter),
                p2: (0.005, -0.02, 0.02, 50, formatter),
-               r: (2, 2, 5, 3),  # another way to create an integer slider
+               # integer parameter created with param
+               r: param.Integer(2, softbounds=(2, 5), label="r"),
+               # integer parameter created with usual syntax
                c: (3, 1, 5, 4)
            },
-           is_polar = True,
            use_latex = False,
            backend = BB,
            aspect = "equal",
@@ -1208,7 +1244,7 @@ def iplot(*args, show=True, **kwargs):
     =====
 
     1. This function is specifically designed to work within Jupyter Notebook.
-       However, it is also possible to use it from a regular Python console,
+       It is also possible to use it from a regular Python console,
        by executing: ``iplot(..., servable=True)``, which will create a server
        process loading the interactive plot on the browser.
        However, ``K3DBackend`` is not supported in this mode of operation.
@@ -1219,7 +1255,7 @@ def iplot(*args, show=True, **kwargs):
        * a pane containing the widgets.
        * a pane containing the chart. We can further customize this container
          by setting the ``pane_kw`` dictionary. Please, read its documentation
-         to understand the availabel options.
+         to understand the available options.
 
     3. Some examples use an instance of ``PrintfTickFormatter`` to format the
        value shown by a slider. This class is exposed by Bokeh, but can be
@@ -1246,8 +1282,8 @@ def iplot(*args, show=True, **kwargs):
 
     7. Once this module has been loaded, there could be problems with all
        other plotting functions when using ``BokehBackend``, namely the
-       figure won't show up in the output cell. If that is the case, we need
-       to turn off  automatic updates on panning by setting
+       figure won't show up in the output cell. If that is the case, we might
+       try to turn off automatic updates on panning by setting
        ``update_event=False`` in the function call.
 
     8. When ``BokehBackend`` is used:
@@ -1256,9 +1292,8 @@ def iplot(*args, show=True, **kwargs):
        * rendering of gradient lines is slow.
        * color bars might not update their ranges.
 
-    9. Once this module has been loaded and ``iplot`` has been executed, if
-       the kernel of the notebook needs to be restarted, the safest procedure
-       is the following:
+    9. Once this module has been loaded and ``iplot`` has been executed, the
+       safest procedure to restart Jupyter Notebook's kernel is the following:
 
        * save the current notebook.
        * close the notebook and Jupyter server.
@@ -1343,7 +1378,7 @@ def create_widgets(params, **kwargs):
     Examples
     ========
 
-    .. jupyter-execute::
+    .. code-block:: python
 
        from sympy.abc import x, y, z
        from spb.interactive import create_widgets
